air_exceedances() returns exceedances for a component by station and month.
air_exceedances_types() returns a list of all exceedances types.
Arguments
- component
ID of component (see air_components)
- year
A 4-digit year
air_exceedances() returns exceedances for a component by station and month.
air_exceedances_types() returns a list of all exceedances types.
ID of component (see air_components)
A 4-digit year